@@ -5,7 +5,8 @@
 #' @export
 BF.glm <- function(x,
                    hypothesis = NULL,
-                   prior = NULL,
+                   prior.hyp = NULL,
+                   complement = TRUE,
                    ...){
 
   Args <- as.list(match.call()[-1])
@@ -13,6 +14,9 @@ BF.glm <- function(x,
   Args$x <- get_est$estimate
   Args$Sigma <- get_est$Sigma[[1]]
   Args$n <- nobs(x)
+  Args$hypothesis <- hypothesis
+  Args$prior.hyp <- prior.hyp
+  Args$complement <- complement
   out <- do.call(BF, Args)
   out$model <- x
   out$call <- match.call()
