@@ -3,32 +3,29 @@
 
 
 subroutine estimate_postmeancov_fisherz(postZmean, postZcov, P, numcorr, K, numG, BHat, sdHat, CHat, XtXi, samsize0, Njs, &
-    Ygroups, Xgroups, Ntot, C_quantiles, sigma_quantiles, B_quantiles, BDrawsStore, sigmaDrawsStore, CDrawsStore, &
-    seed)
+    Ygroups, Xgroups, Ntot, C_quantiles, sigma_quantiles, B_quantiles, BDrawsStore, sigmaDrawsStore, CDrawsStore, seed)
 !
     implicit none
 
-    integer, intent(in) :: P, numcorr, K, numG, samsize0, Njs(numG), Ntot, seed
-    real(8), intent(in) :: BHat(numG,K,P), sdHat(2*numG,P), CHat(numG,P,P), XtXi(numG,K,K)
-    real(8), intent(out):: postZmean(numcorr,1), postZcov(numcorr,numcorr), Ygroups(numG,Ntot,P), Xgroups(numG,Ntot,K),&
-                           B_quantiles(numG,K,P,3), C_quantiles(numG,P,P,3), sigma_quantiles(numG,P,3), &
-                           BDrawsStore(samsize0,numG,K,P), sigmaDrawsStore(samsize0,numG,P), &
-                           CDrawsStore(samsize0,numG,P,P)
-    real(8)             :: BDraws(numG,K,P), sigmaDraws(numG,P), CDraws(numG,P,P), Ccan(P,P), Ds(P,P), dummyPP2(P,P), &
-                           CcanInv(P,P), Ccurr(P,P), CcurrInv(P,P), SS1(P,P), rnunif(1), sdMH(numG,P), errorMatj(P,P), &
-                           sigma_can(P), aa, bb, SigmaMat(P,P), R_MH, epsteps(P,P), logR_MH, diffmat(Ntot,P), &
-                           varz1, varz2, varz1z2Plus, varz1z2Min, Cinv(P,P), Zcorr_sample(samsize0,numcorr), &
-                           acceptSigma(numG,P), acceptC(numG), covBeta(P*K,P*K), betaDrawj(1,P*K), dummyPP(P,P), &
-                           dummy3(samsize0), dummy2(samsize0), meanO(P*K), para(((P*K)*((P*K)+3)/2 + 1)), SS2(P,P)
-    integer             :: s1, g1, i1, corrteller, c1, c2, p1, p2, k1, errorflag, lower_int, median_int, upper_int, &
-                           iseed!, nn
-!    integer, allocatable, dimension(:) :: iseed
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
+
+    integer(i6), intent(in) :: P, numcorr, K, numG, samsize0, Njs(numG), Ntot, seed
+    real(r15), intent(in)   :: BHat(numG,K,P), sdHat(2*numG,P), CHat(numG,P,P), XtXi(numG,K,K), Ygroups(numG,Ntot,P), &
+                               Xgroups(numG,Ntot,K)
+    real(r15), intent(out)  :: postZmean(numcorr,1), postZcov(numcorr,numcorr), B_quantiles(numG,K,P,3), &
+                               C_quantiles(numG,P,P,3), sigma_quantiles(numG,P,3), BDrawsStore(samsize0,numG,K,P), &
+                               sigmaDrawsStore(samsize0,numG,P), CDrawsStore(samsize0,numG,P,P)
+    real(r15)               :: BDraws(numG,K,P), sigmaDraws(numG,P), CDraws(numG,P,P), Ccan(P,P), Ds(P,P), dummyPP2(P,P), &
+                            CcanInv(P,P), Ccurr(P,P), CcurrInv(P,P), SS1(P,P), rnunif(1), sdMH(numG,P), errorMatj(P,P), &
+                            sigma_can(P), aa, bb, SigmaMat(P,P), R_MH, epsteps(P,P), logR_MH, diffmat(Ntot,P), &
+                            varz1, varz2, varz1z2Plus, varz1z2Min, Cinv(P,P), Zcorr_sample(samsize0,numcorr), &
+                            acceptSigma(numG,P), acceptC(numG), covBeta(P*K,P*K), betaDrawj(1,P*K), dummyPP(P,P), &
+                            dummy3(samsize0), dummy2(samsize0), meanO(P*K), para(((P*K)*((P*K)+3)/2 + 1)), SS2(P,P)
+    integer(i6)             :: s1, g1, i1, corrteller, c1, c2, p1, p2, k1, errorflag, lower_int, median_int, upper_int, &
+                               iseed
 !
     !set seed
-    !call RANDOM_SEED(size=nn)
-    !allocate(iseed(nn))
-    !iseed(:)=seed
-    !call RANDOM_SEED(put=iseed)
     iseed = seed
 !
     !initial posterior draws start at MLEs
@@ -254,10 +251,13 @@ function runiform ( iseed )
 !
   implicit none
 
-  integer ( kind = 4 ), parameter :: i4_huge = 2147483647
-  integer ( kind = 4 ) k
-  real ( kind = 8 ) runiform
-  integer ( kind = 4 ) iseed
+  integer, parameter :: r15 = selected_real_kind(15)
+  integer, parameter :: i6 = selected_int_kind(6)
+
+  integer ( kind = i6 ), parameter :: i4_huge = 2147483647
+  integer ( kind = i6 ) k
+  real ( kind = r15 ) runiform
+  integer ( kind = i6 ) iseed
 
   k = iseed / 127773
 
@@ -267,7 +267,7 @@ function runiform ( iseed )
     iseed = iseed + i4_huge
   end if
 
-  runiform = real ( iseed, kind = 8 ) * 4.656612875D-10
+  runiform = real ( iseed, kind = r15 ) * 4.656612875D-10
 
 return
 end function
@@ -303,24 +303,27 @@ function stvaln ( p )
 !
   implicit none
 
+  integer, parameter :: r15 = selected_real_kind(15)
+  integer, parameter :: i6 = selected_int_kind(6)
+
   !real ( kind = 8 ) eval_pol
-  real ( kind = 8 ) p
-  real ( kind = 8 ) sgn
-  real ( kind = 8 ) stvaln
-  real ( kind = 8 ), parameter, dimension(0:4) :: xden = (/ &
+  real ( kind = r15 ) p
+  real ( kind = r15 ) sgn
+  real ( kind = r15 ) stvaln
+  real ( kind = r15 ), parameter, dimension(0:4) :: xden = (/ &
     0.993484626060D-01, &
     0.588581570495D+00, &
     0.531103462366D+00, &
     0.103537752850D+00, &
     0.38560700634D-02 /)
-  real ( kind = 8 ), parameter, dimension(0:4) :: xnum = (/ &
+  real ( kind = r15 ), parameter, dimension(0:4) :: xnum = (/ &
     -0.322232431088D+00, &
     -1.000000000000D+00, &
     -0.342242088547D+00, &
     -0.204231210245D-01, &
     -0.453642210148D-04 /)
-  real ( kind = 8 ) y
-  real ( kind = 8 ) z
+  real ( kind = r15 ) y
+  real ( kind = r15 ) z
 
   if ( p <= 0.5D+00 ) then
 
@@ -369,13 +372,16 @@ function eval_pol ( a, n, x )
 !
   implicit none
 
-  integer ( kind = 4 ) n
+  integer, parameter :: r15 = selected_real_kind(15)
+  integer, parameter :: i6 = selected_int_kind(6)
 
-  real ( kind = 8 ) a(0:n)
-  real ( kind = 8 ) eval_pol
-  integer ( kind = 4 ) i
-  real ( kind = 8 ) term
-  real ( kind = 8 ) x
+  integer ( kind = i6 ) n
+
+  real ( kind = r15 ) a(0:n)
+  real ( kind = r15 ) eval_pol
+  integer ( kind = i6 ) i
+  real ( kind = r15 ) term
+  real ( kind = r15 ) x
 
   term = a(n)
   do i = n - 1, 0, -1
@@ -450,19 +456,22 @@ function cumnor ( arg )
 !
   implicit none
 
-  real ( kind = 8 ), parameter, dimension ( 5 ) :: a = (/ &
+  integer, parameter :: r15 = selected_real_kind(15)
+  integer, parameter :: i6 = selected_int_kind(6)
+
+  real ( kind = r15 ), parameter, dimension ( 5 ) :: a = (/ &
     2.2352520354606839287D+00, &
     1.6102823106855587881D+02, &
     1.0676894854603709582D+03, &
     1.8154981253343561249D+04, &
     6.5682337918207449113D-02 /)
-  real ( kind = 8 ) arg
-  real ( kind = 8 ), parameter, dimension ( 4 ) :: b = (/ &
+  real ( kind = r15 ) arg
+  real ( kind = r15 ), parameter, dimension ( 4 ) :: b = (/ &
     4.7202581904688241870D+01, &
     9.7609855173777669322D+02, &
     1.0260932208618978205D+04, &
     4.5507789335026729956D+04 /)
-  real ( kind = 8 ), parameter, dimension ( 9 ) :: c = (/ &
+  real ( kind = r15 ), parameter, dimension ( 9 ) :: c = (/ &
     3.9894151208813466764D-01, &
     8.8831497943883759412D+00, &
     9.3506656132177855979D+01, &
@@ -472,8 +481,8 @@ function cumnor ( arg )
     1.1602651437647350124D+04, &
     9.8427148383839780218D+03, &
     1.0765576773720192317D-08 /)
-  real ( kind = 8 ) cumnor
-  real ( kind = 8 ), parameter, dimension ( 8 ) :: d = (/ &
+  real ( kind = r15 ) cumnor
+  real ( kind = r15 ), parameter, dimension ( 8 ) :: d = (/ &
     2.2266688044328115691D+01, &
     2.3538790178262499861D+02, &
     1.5193775994075548050D+03, &
@@ -482,31 +491,31 @@ function cumnor ( arg )
     3.4900952721145977266D+04, &
     3.8912003286093271411D+04, &
     1.9685429676859990727D+04 /)
-  real ( kind = 8 ) del
-  real ( kind = 8 ) eps
-  integer ( kind = 4 ) i
-  real ( kind = 8 ), parameter, dimension ( 6 ) :: p = (/ &
+  real ( kind = r15 ) del
+  real ( kind = r15 ) eps
+  integer ( kind = i6 ) i
+  real ( kind = r15 ), parameter, dimension ( 6 ) :: p = (/ &
     2.1589853405795699D-01, &
     1.274011611602473639D-01, &
     2.2235277870649807D-02, &
     1.421619193227893466D-03, &
     2.9112874951168792D-05, &
     2.307344176494017303D-02 /)
-  real ( kind = 8 ), parameter, dimension ( 5 ) :: q = (/ &
+  real ( kind = r15 ), parameter, dimension ( 5 ) :: q = (/ &
     1.28426009614491121D+00, &
     4.68238212480865118D-01, &
     6.59881378689285515D-02, &
     3.78239633202758244D-03, &
     7.29751555083966205D-05 /)
-  real ( kind = 8 ), parameter :: root32 = 5.656854248D+00
-  real ( kind = 8 ), parameter :: sixten = 16.0D+00
-  real ( kind = 8 ), parameter :: sqrpi = 3.9894228040143267794D-01
-  real ( kind = 8 ), parameter :: thrsh = 0.66291D+00
-  real ( kind = 8 ) x
-  real ( kind = 8 ) xden
-  real ( kind = 8 ) xnum
-  real ( kind = 8 ) y
-  real ( kind = 8 ) xsq
+  real ( kind = r15 ), parameter :: root32 = 5.656854248D+00
+  real ( kind = r15 ), parameter :: sixten = 16.0D+00
+  real ( kind = r15 ), parameter :: sqrpi = 3.9894228040143267794D-01
+  real ( kind = r15 ), parameter :: thrsh = 0.66291D+00
+  real ( kind = r15 ) x
+  real ( kind = r15 ) xden
+  real ( kind = r15 ) xnum
+  real ( kind = r15 ) y
+  real ( kind = r15 ) xsq
 !
 !  Machine dependent constants
 !
@@ -623,18 +632,21 @@ function cumnor ( arg )
 !
   implicit none
 
-  real ( kind = 8 ) cum
-  real ( kind = 8 ) dinvnr
-  real ( kind = 8 ) dx
-  real ( kind = 8 ), parameter :: eps = 1.0D-13
-  integer ( kind = 4 ) i
-  integer ( kind = 4 ), parameter :: maxit = 100
-  real ( kind = 8 ) p
-  real ( kind = 8 ) pp
-  real ( kind = 8 ), parameter :: r2pi = 0.3989422804014326D+00
-  real ( kind = 8 ) strtx
-  !real ( kind = 8 ) stvaln
-  real ( kind = 8 ) xcur
+  integer, parameter :: r15 = selected_real_kind(15)
+  integer, parameter :: i6 = selected_int_kind(6)
+
+  real ( kind = r15 ) cum
+  real ( kind = r15 ) dinvnr
+  real ( kind = r15 ) dx
+  real ( kind = r15 ), parameter :: eps = 1.0D-13
+  integer ( kind = i6 ) i
+  integer ( kind = i6 ), parameter :: maxit = 100
+  real ( kind = r15 ) p
+  real ( kind = r15 ) pp
+  real ( kind = r15 ), parameter :: r2pi = 0.3989422804014326D+00
+  real ( kind = r15 ) strtx
+  !real ( kind = r15 ) stvaln
+  real ( kind = r15 ) xcur
 
   pp = min ( p, 1-p )
   strtx = stvaln(pp)
@@ -674,10 +686,13 @@ subroutine kronecker(dimA,dimB,A,B,AB)
 !
     implicit none
 !
-    integer, intent(in) :: dimA, dimB
-    real(8), intent(in)    :: A(dimA,dimA), B(dimB,dimB) !dummy arguments
-    real(8), intent(out)   :: AB(dimA*dimB,dimA*dimB) !output matrix of the kronecker product
-    integer             :: i,j !loop counters
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
+!
+    integer(i6), intent(in)  :: dimA, dimB
+    real(r15), intent(in)    :: A(dimA,dimA), B(dimB,dimB) !dummy arguments
+    real(r15), intent(out)   :: AB(dimA*dimB,dimA*dimB) !output matrix of the kronecker product
+    integer(i6)              :: i,j !loop counters
 !
     do i=1,dimA
         do j=1,dimA
@@ -689,25 +704,30 @@ end subroutine kronecker
 
 
 
-REAL(8) FUNCTION sdot(N,SX,INCX,SY,INCY)
+FUNCTION sdot(N,SX,INCX,SY,INCY)
  !
  !  -- Reference BLAS level1 routine (version 3.8.0) --
  !  -- Reference BLAS is a software package provided by Univ. of Tennessee,    --
  !  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
  !     November 2017
+ !
+    implicit none
+ !
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
  !
  !     .. Scalar Arguments ..
-    INTEGER INCX,INCY,N
+    INTEGER(i6) INCX,INCY,N
  !     ..
-  !    .. Array Arguments ..
-    REAL(8) SX(*),SY(*)
+ !     .. Array Arguments ..
+    REAL(r15) SX(*),SY(*)
  !    ..
  !
  !  =====================================================================
  !
  !     .. Local Scalars ..
-    REAL(8) STEMP
-    INTEGER I,IX,IY,M,MP1
+    REAL(r15) STEMP, sdot
+    INTEGER(i6) I,IX,IY,M,MP1
  !     ..
  !     .. Intrinsic Functions ..
     INTRINSIC mod
@@ -758,23 +778,35 @@ END FUNCTION sdot
 
 function diag(A, n)
 
-    integer n,i
-    real(8) A(n), check(n,n)
-    real(8) diag(n,n)
-
+    implicit none
+!
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
+!
+    integer(i6) n,i
+    real(r15) A(n), check(n,n)
+    real(r15) diag(n,n)
 
     check = 0
     do i=1,n
         check(i,i)=A(i)
     end do
     diag(:,:)=check(:,:)
+
     return
+
 end function diag
 
+
 function diagonals(A, n)
 
-    integer n,i
-    real(8) A(n,n), diagonals(n), check(n)
+    implicit none
+!
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
+
+    integer(i6) n,i
+    real(r15) A(n,n), diagonals(n), check(n)
 
     do i=1,n
         check(i)= A(i,i)
@@ -792,16 +824,20 @@ end function diagonals
 !http://www.tutor.ms.unimelb.edu.au/matrix/matrix_inverse.html
 SUBROUTINE FINDInv(matrix, inverse, n, errorflag)
     IMPLICIT NONE
+
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
+
     !Declarations
-    INTEGER, INTENT(IN) :: n
-    REAL(8), INTENT(IN) :: matrix(n,n)  !Input matrix
-    INTEGER, INTENT(OUT) :: errorflag  !Return error status. -1 for error, 0 for normal
-    REAL(8), INTENT(OUT) :: inverse(n,n) !Inverted matrix
+    INTEGER(i6), INTENT(IN)  :: n
+    REAL(r15), INTENT(IN)    :: matrix(n,n)  !Input matrix
+    INTEGER(i6), INTENT(OUT) :: errorflag  !Return error status. -1 for error, 0 for normal
+    REAL(r15), INTENT(OUT)   :: inverse(n,n) !Inverted matrix
 
     LOGICAL :: FLAG = .TRUE.
-    INTEGER :: i, j, k
-    REAL(8) :: m
-    REAL(8), DIMENSION(n,2*n) :: augmatrix !augmented matrix
+    INTEGER(i6) :: i, j, k
+    REAL(r15) :: m
+    REAL(r15), DIMENSION(n,2*n) :: augmatrix !augmented matrix
 
     inverse = eye(n)
     !Augment input matrix with an identity matrix
@@ -888,11 +924,17 @@ recursive function det(a,n,permanent) result(accumulation)
     ! setting permanent to 1 computes the permanent.
     ! setting permanent to -1 computes the determinant.
 
-    integer, intent(in) :: n, permanent
-    real(8), dimension(n,n), intent(in) :: a
-    real(8), dimension(n-1, n-1) :: b
-    real(8) :: accumulation
-    integer :: i, sgn
+    IMPLICIT NONE
+
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
+
+    integer(i6), intent(in) :: n, permanent
+    real(r15), dimension(n,n), intent(in) :: a
+    real(r15), dimension(n-1, n-1) :: b
+    real(r15) :: accumulation
+    integer(i6) :: i, sgn
+
     if (n .eq. 1) then
       accumulation = a(1,1)
     else
@@ -905,6 +947,7 @@ recursive function det(a,n,permanent) result(accumulation)
         sgn = sgn * permanent
       enddo
     endif
+
 end function det
 
 
@@ -940,14 +983,17 @@ function rnormal (iseed)
 !
   implicit none
 
-  real ( kind = 8 ) r1
-  real ( kind = 8 ) r2
-  real ( kind = 8 ) r3
-  real ( kind = 8 ) rnormal
-  real ( kind = 8 ), parameter :: pi = 3.141592653589793D+00
-  !real ( kind = 8 ) GG
-  real ( kind = 8 ) x
-  integer ( kind = 4 ) iseed
+  integer, parameter :: r15 = selected_real_kind(15)
+  integer, parameter :: i6 = selected_int_kind(6)
+
+  real ( kind = r15 ) r1
+  real ( kind = r15 ) r2
+  real ( kind = r15 ) r3
+  real ( kind = r15 ) rnormal
+  real ( kind = r15 ), parameter :: pi = 3.141592653589793D+00
+  !real ( kind = r15 ) GG
+  real ( kind = r15 ) x
+  integer ( kind = i6 ) iseed
 
   !nseed = 1344
   r1 = runiform(iseed)
@@ -969,9 +1015,14 @@ end function rnormal
 
 function eye(n)
 
-    integer i,n
-    real(8) eye(n,n)
-    real(8) check(n,n)
+    implicit none
+
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
+
+    integer(i6) i,n
+    real(r15) eye(n,n)
+    real(r15) check(n,n)
 
     check=0
     do i=1,n
@@ -988,14 +1039,17 @@ end function eye
 subroutine gen_wish(A,nu,B,P,iseed)
 !
     implicit none
+!
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
 !
     !Declare local variables
 
-    integer, intent (in)    :: nu,P,iseed
-    real(8), intent (in)    :: A(P,P)
-    real(8), intent (out)   :: B(P,P)
-    real(8)                 :: RNmat(nu,P),para((P*(P+3)/2) + 1),m0(P)
-    integer                 :: i
+    integer(i6), intent (in)  :: nu,P,iseed
+    real(r15), intent (in)    :: A(P,P)
+    real(r15), intent (out)   :: B(P,P)
+    real(r15)                 :: RNmat(nu,P),para((P*(P+3)/2) + 1),m0(P)
+    integer(i6)               :: i
 !
     !sample from Wishart distribution as in Press (2005, p. 109)
     m0=0
@@ -1015,15 +1069,19 @@ end subroutine gen_wish
 
 !
 subroutine robust_covest(m, betas1, betas2, mn1, mn2, varb1, varb2, varb1b2Plus, varb1b2Min)
+
     implicit none
+!
+    integer, parameter :: r15 = selected_real_kind(15)
+    integer, parameter :: i6 = selected_int_kind(6)
 !
     !Declare local variables
-    integer, intent(in)    :: m
-    real(8), intent(in)    :: betas1(m), betas2(m), mn1, mn2
-    real(8), intent(out)   :: varb1, varb2, varb1b2Plus, varb1b2Min
+    integer(i6), intent(in)  :: m
+    real(r15), intent(in)    :: betas1(m), betas2(m), mn1, mn2
+    real(r15), intent(out)   :: varb1, varb2, varb1b2Plus, varb1b2Min
 
-    real(8)                :: dummy1(m), dummy2(m), Phi075, xxx
-    integer                :: mmin, i
+    real(r15)                :: dummy1(m), dummy2(m), Phi075, xxx
+    integer(i6)              :: mmin, i
 !
     xxx=0.75
     Phi075 = dinvnr(xxx)
@@ -1080,8 +1138,13 @@ end subroutine
 
 SUBROUTINE piksrt(n,arr)
 
-  integer:: n, i,j
-  real(8):: arr(n), a
+  implicit none
+!
+  integer, parameter :: r15 = selected_real_kind(15)
+  integer, parameter :: i6 = selected_int_kind(6)
+
+  integer(i6):: n, i,j
+  real(r15):: arr(n), a
 
   do j=2, n
     a=arr(j)
@@ -1092,7 +1155,9 @@ SUBROUTINE piksrt(n,arr)
   i=0
 10  arr(i+1)=a
   end do
+
   return
+
 END SUBROUTINE
 
 
@@ -1134,14 +1199,20 @@ SUBROUTINE setgmn(meanv,covm,p,parm)
 !                                             REAL PARM(P*(P+3)/2 + 1)
 !
 !**********************************************************************
+
+      implicit none
+!
+      integer, parameter :: r15 = selected_real_kind(15)
+      integer, parameter :: i6 = selected_int_kind(6)
+
 !     .. Scalar Arguments ..
-      INTEGER p
+      INTEGER(i6) p
 !     ..
 !     .. Array Arguments ..
-      REAL(8) covm(p,p),meanv(p),parm(p*(p+3)/2+1)
+      REAL(r15) covm(p,p),meanv(p),parm(p*(p+3)/2+1)
 !     ..
 !     .. Local Scalars ..
-      INTEGER i,icount,info,j
+      INTEGER(i6) i,icount,info,j
 !     ..
 !     .. External Subroutines ..
 
@@ -1228,15 +1299,21 @@ SUBROUTINE genmn(parm,x,p,iseed)
   !     3) trans(A)E + MEANV ~ N(MEANV,!OVM)
   !
   !**********************************************************************
+  !
+        implicit none
+  !
+        integer, parameter :: r15 = selected_real_kind(15)
+        integer, parameter :: i6 = selected_int_kind(6)
+  !
   !     .. Array Arguments ..
-        integer, intent(in) :: p, iseed
-        real(8), intent(in) :: parm(p*(p+3)/2 + 1)
-        real(8)             :: work(p)
-        real(8), intent(out):: x(p)
+        integer(i6), intent(in) :: p, iseed
+        real(r15), intent(in)   :: parm(p*(p+3)/2 + 1)
+        real(r15)               :: work(p)
+        real(r15), intent(out)  :: x(p)
   !     ..
   !     .. Local Scalars ..
-        real(8) ae
-        INTEGER i,icount,j
+        real(r15) ae
+        INTEGER(i6) i,icount,j
   !    ..
   !     .. External Functions ..
   !     ..
@@ -1277,9 +1354,14 @@ END SUBROUTINE
 
 subroutine spofa(a,lda,n,info)
 
-      integer lda,n,info
-      real(8) a(lda,n)
-
+      implicit none
+!
+      integer, parameter :: r15 = selected_real_kind(15)
+      integer, parameter :: i6 = selected_int_kind(6)
+!
+      integer(i6) lda,n,info
+      real(r15) a(lda,n)
+!
 !     spofa factors a real symmetric positive definite matrix.
 !
 !     spofa is usually called by spoco, but it can be called
@@ -1320,11 +1402,10 @@ subroutine spofa(a,lda,n,info)
 !
 !     internal variables
 !
-      real(8) t
-      real(8) s
-      integer j,jm1,k
+      real(r15) t
+      real(r15) s
+      integer(i6) j,jm1,k
 !     begin block with ...exits to 40
-!
 !
          do 30 j = 1, n
             info = j
