@@ -21,8 +21,14 @@ test2 <- list(start=c(1,2,5,2,1,7,3,4,8,8),
               pred=c(1,0,0,1,0,1,1,1,0,0))
 fit <- coxph(Surv(start, stop, event) ~ pred, test2)
 
-out <- BF(fit, "pred > .5")
-
+out <- BF(fit, hypothesis = "pred > .5; pred = .5")
 test_that("BF.coxph returns correct results,", {
   expect_true(out$PHP_confirmatory[1] < .5 & out$PHP_confirmatory[2] > .5)
 })
+
+out <- BF(fit, hypothesis = "pred > .5; pred = .5",complement = FALSE)
+test_that("BF.coxph returns correct results,", {
+  expect_equivalent(
+    out$PHP_confirmatory, c(0.194,0.806), tol = .1
+  )
+})
